@@ -1,6 +1,7 @@
-#' Optimize the objective function using an adaptive random search algorithm for D-family designs. 
+#' Optimize the objective function using an adaptive random search algorithm for D-family and E-family designs. 
 #' 
-#' Optimize the objective function using an adaptive random search algorithm.
+#' Optimize the objective function using an adaptive random search algorithm.  
+#' Optimization can be performed for both D-family and E-family designs.
 #' The function works for both discrete and continuous optimization variables.
 #' This function takes information from the PopED database supplied as an argument.
 #' The PopED database supplies information about the the model, parameters, design and methods to use.
@@ -11,12 +12,19 @@
 #' @inheritParams evaluate.fim
 #' @inheritParams Doptim
 #' @inheritParams create.poped.database
+#' @inheritParams calc_ofv_and_fim
 #' @param cfaxt First step factor for sample times 
 #' @param opt_xt Should the sample times be optimized?
 #' @param opt_a Should the continuous design variables be optimized?
 #' @param opt_x Should the discrete design variables be optimized?
 #' @param approx_type Approximation method for model, 0=FO, 1=FOCE, 2=FOCEI, 3=FOI.
-#' @param iter The number of iterations entered into the \code{\link{blockheader}} function.
+#' @param iter The number of iterations entered into the \code{blockheader_2} function.
+#' @param header_flag Should the header text be printed out?
+#' @param footer_flag Should the footer text be printed out?
+#' @param out_file Which file should the output be directed to?  A string, a file handle using 
+#'        \code{\link{file}} or \code{""} will output to the screen.
+#' @param compute_inv should the inverse of the FIM be used to compute expected RSE values?  Often not needed
+#'        except for diagnostic purposes.
 #' @param ... arguments passed to \code{\link{evaluate.fim}} and \code{\link{ofv_fim}}.
 #' 
 #' 
@@ -29,47 +37,43 @@
 #' }
 #' @family Optimize
 #' 
-#' @example tests/testthat/examples_fcn_doc/warfarin_optimize.R
+#' @example tests/testthat/examples_fcn_doc/warfarin_ed.R
 #' @example tests/testthat/examples_fcn_doc/examples_RS_opt.R
 #' @export
-## Function translated using 'matlab.to.r()'
-## Then manually adjusted to make work
-## Author: Andrew Hooker
-
 RS_opt <- function(poped.db,
-                   ni=NULL, 
-                   xt=NULL, 
-                   model_switch=NULL, 
-                   x=NULL, 
-                   a=NULL, 
-                   bpopdescr=NULL, 
-                   ddescr=NULL, 
-                   maxxt=NULL, 
-                   minxt=NULL,
-                   maxa=NULL,
-                   mina=NULL,
-                   fmf=0,
-                   dmf=0,
-                   trflag = TRUE,
-                   opt_xt=poped.db$settings$optsw[2],
-                   opt_a=poped.db$settings$optsw[4],
-                   opt_x=poped.db$settings$optsw[3],
-                   cfaxt=poped.db$settings$cfaxt, 
-                   cfaa=poped.db$settings$cfaa,
-                   rsit=poped.db$settings$rsit,
-                   rsit_output=poped.db$settings$rsit_output,
-                   fim.calc.type=poped.db$settings$iFIMCalculationType,
-                   #ofv_calc_type=poped.db$settings$ofv_calc_type,
-                   #ds_index = poped.db$parameters$ds_index
-                   approx_type=poped.db$settings$iApproximationMethod,
-                   iter=1,
-                   ...){
-  # change so that only one output file and one summary file
-  # enable turning off of writing output
-  # allow for only global structure to be passed. or only input needed for
-  # function
-  # fix summary file output.
-  # fix so that it works for ed as well as d...needs to be more general.
+                       ni=NULL, 
+                       xt=NULL, 
+                       model_switch=NULL, 
+                       x=NULL, 
+                       a=NULL, 
+                       bpopdescr=NULL, 
+                       ddescr=NULL, 
+                       maxxt=NULL, 
+                       minxt=NULL,
+                       maxa=NULL,
+                       mina=NULL,
+                       fmf=0,
+                       dmf=0,
+                       trflag = TRUE,
+                       opt_xt=poped.db$settings$optsw[2],
+                       opt_a=poped.db$settings$optsw[4],
+                       opt_x=poped.db$settings$optsw[3],
+                       cfaxt=poped.db$settings$cfaxt, 
+                       cfaa=poped.db$settings$cfaa,
+                       rsit=poped.db$settings$rsit,
+                       rsit_output=poped.db$settings$rsit_output,
+                       fim.calc.type=poped.db$settings$iFIMCalculationType,
+                       approx_type=poped.db$settings$iApproximationMethod,
+                       iter=NULL,
+                       d_switch=poped.db$settings$d_switch,
+                       use_laplace=poped.db$settings$iEDCalculationType,
+                       laplace.fim=FALSE,
+                       header_flag=TRUE,
+                       footer_flag=TRUE,
+                       out_file=NULL,
+                       compute_inv=TRUE,
+                       ...){
+  
   
   # Only get inputs that are needed, not double inputs
   # needed inputs to function: get first then run function
@@ -97,7 +101,7 @@ RS_opt <- function(poped.db,
       eval(parse(text=paste(capture.output(default_args[[i]]),"<-",i)))
     }
   }
-    
+  
   downsize.list <- downsizing_general_design(poped.db)
   if(is.null(ni)) ni <- downsize.list$ni
   if(is.null(xt)) xt <- downsize.list$xt
@@ -111,6 +115,16 @@ RS_opt <- function(poped.db,
   if(is.null(maxa)) maxa <- downsize.list$maxa
   if(is.null(mina)) mina <- downsize.list$mina
   
+  # ----------------- initialization of optimum variables 
+  xtopt=xt
+  xopt=x
+  aopt=a
+  
+  if(sum(opt_x,opt_a,opt_xt)==0){
+    cat("No optimization variables specified in input\n")
+    return(invisible(list( xtopt= xtopt,xopt=xopt,aopt=aopt,fmf=fmf,dmf=dmf,poped.db =poped.db )))   
+  }  
+  
   loops=TRUE # for building a RS without for loops use FALSE (developmental)
   
   # ----------------- initialization of size variables
@@ -130,77 +144,70 @@ RS_opt <- function(poped.db,
   d=getfulld(ddescr[,2,drop=F],poped.db$parameters$covd)
   docc_full = getfulld(poped.db$parameters$docc[,2,drop=F],poped.db$parameters$covdocc)
   
-  if((fmf==0) ){
-    #     tot.time <- 0
-    #     n <- 100
-    #     for(i in 1:n){
-    #       times <- system.time(mftot(model_switch,poped.db$design$groupsize,ni,xt,x,a,bpop,d,poped.db$parameters$sigma,docc_full,poped.db))
-    #       tot.time <- tot.time + times
-    #     }
-    #     avg.time <- tot.time/n
-    #     avg.time
-    #     
-    #     system.time(for(i in 1:100) mftot(model_switch,poped.db$design$groupsize,ni,xt,x,a,bpop,d,poped.db$parameters$sigma,docc_full,poped.db))
-    #     system.time(mftot(model_switch,poped.db$design$groupsize,ni,xt,x,a,bpop,d,poped.db$parameters$sigma,docc_full,poped.db))
-    #     
-    #     system.time(for(i in 1:100){
-    #     evaluate.fim(poped.db,
-    #                  bpop.val=bpop,
-    #                  d_full=d,
-    #                  docc_full=docc_full,
-    #                  sigma_full=poped.db$parameters$sigma,
-    #                  model_switch=model_switch,
-    #                  ni=ni,
-    #                  xt=xt,
-    #                  x=x,
-    #                  a=a,
-    #                  groupsize=poped.db$design$groupsize,
-    #                  ...)
-    #     }    
-    #     )
-    #     
-    fmf <- evaluate.fim(poped.db,
-                        bpop.val=bpop,
-                        d_full=d,
-                        docc_full=docc_full,
-                        sigma_full=poped.db$parameters$sigma,
-                        model_switch=model_switch,
-                        ni=ni,
-                        xt=xt,
-                        x=x,
-                        a=a,
-                        groupsize=poped.db$design$groupsize,
-                        fim.calc.type=fim.calc.type,
-                        ...)
-    
-    #     returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt,x,a,bpop,d,poped.db$parameters$sigma,docc_full,poped.db) 
-    #     fmf <- returnArgs[[1]]
-    #     poped.db <- returnArgs[[2]]
-  }
-  if((dmf==0)){
-    dmf=ofv_fim(fmf,poped.db,...)
-  }
+  output <- calc_ofv_and_fim(poped.db,
+                             ofv=dmf,
+                             fim=fmf, 
+                             d_switch=d_switch,  
+                             bpopdescr=bpopdescr, 
+                             ddescr=ddescr,
+                             bpop=bpop, 
+                             d=d, 
+                             docc_full= docc_full, 
+                             model_switch=model_switch, 
+                             ni=ni, 
+                             xt=xt, 
+                             x=x, 
+                             a=a, 
+                             fim.calc.type=fim.calc.type,
+                             use_laplace=use_laplace,
+                             laplace.fim=laplace.fim, 
+                             ...)
+  fmf <- output$fim
+  dmf <- output$ofv
   fmf_init <- fmf
   dmf_init <- dmf
   
-  #==========================================
-  # turn warnings off
-  #==========================================
-  ## warning('off','MATLAB:nearlySingularMatrix');
+  #   # ------------------ Write summary output file header
+  #   param_cvs_init=NULL
+  #   if((trflag && header_flag)){
+  #     fn=blockheader_2(poped.db,name='RS',iter=iter,e_flag=!d_switch,
+  #                      opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,
+  #                      opt_inds=F,opt_samps=F,
+  #                      fmf=fmf,dmf=dmf,
+  #                      bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma,
+  #                      out_file=out_file,compute_inv=compute_inv)
+  #     if(is.matrix(fmf) && compute_inv){ 
+  #       param_vars_init=diag_matlab(inv(fmf))
+  #       returnArgs <-  get_cv(param_vars_init,bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma,poped.db) 
+  #       params_init <- returnArgs[[1]]
+  #       param_cvs_init <- returnArgs[[2]]
+  #     }
+  #   } 
+  #   
+  #--------------------- write out info to a file
+  fn=blockheader(poped.db,name="RS",e_flag=!d_switch,iter=iter,
+                   opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,
+                   opt_inds=F,opt_samps=F,
+                   fmf=fmf,dmf=dmf,
+                   bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma,
+                   out_file=out_file,
+                   trflag=trflag,
+                   header_flag=header_flag,
+                   compute_inv=compute_inv,
+                   ...)
   
   
-  # ------------------ Write summary output file header
-  if((trflag)){
-    fn=blockheader(poped.db,name='RS',iter=iter,
-                     opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,
-                     opt_inds=F,opt_samps=F,
-                     fmf=fmf_init,dmf=dmf_init,
-                     bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma)
-    param_vars_init=diag_matlab(inv(fmf))
-    returnArgs <-  get_cv(param_vars_init,bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma,poped.db) 
-    params_init <- returnArgs[[1]]
-    param_cvs_init <- returnArgs[[2]]
-  }
+  #   #=====open a file to write to if not already open
+  #   if(!exists("fn")){
+  #     fn <- out_file
+  #     if(is.null(fn)) fn <- ''
+  #     if(!any(class(fn)=="file") && !(fn=='')){
+  #       fn=file(fn,'w')
+  #       if(fn==-1){
+  #         stop(sprintf('output file could not be opened'))
+  #       }
+  #     } 
+  #   }
   
   # if((poped.db$settings$bShowGraphs && trflag)){
   #     figure(1)
@@ -212,10 +219,7 @@ RS_opt <- function(poped.db,
   itvector <- c()
   dmfvector <- c()
   
-  # ----------------- initialization of optimum variables (and old)
-  xtopt=xt
-  xopt=x
-  aopt=a
+  
   
   # ----------------- RS variables initialization
   dxt=(maxxt-minxt)/poped.db$settings$rslxt
@@ -235,7 +239,8 @@ RS_opt <- function(poped.db,
   
   if((trflag)){
     # NEEDS TO BE FIXED with right output
-    Dtrace(fn,0,ni,xtopt,xopt,aopt,matrix(0,0,0),matrix(0,0,0),dmf,matrix(0,0,0),matrix(0,0,0),matrix(0,0,0),itvector,dmfvector,poped.db)
+    Dtrace(fn,0,ni,xtopt,xopt,aopt,matrix(0,0,0),matrix(0,0,0),dmf,matrix(0,0,0),
+           matrix(0,0,0),matrix(0,0,0),itvector,dmfvector,poped.db)
   }
   
   if((poped.db$settings$parallel$bParallelRS)){
@@ -287,13 +292,14 @@ RS_opt <- function(poped.db,
         fmf=designsout[[it]]$FIM
       }
       
-      if((trflag && (rem(it,rsit_output)==0 || it==rsit))){
+      if((trflag && ((it %% rsit_output)==0 || it==rsit))){
         itvector[ceiling(it/rsit_output)+1]=it
         dmfvector[ceiling(it/rsit_output)+1]=dmf
-        Dtrace(fn,it,ni,xtopt,xopt,aopt,matrix(0,0,0),matrix(0,0,0),dmf,matrix(0,0,0),matrix(0,0,0),matrix(0,0,0),itvector,dmfvector,poped.db)
+        Dtrace(fn,it,ni,xtopt,xopt,aopt,matrix(0,0,0),matrix(0,0,0),dmf,matrix(0,0,0),
+               matrix(0,0,0),matrix(0,0,0),itvector,dmfvector,poped.db)
       }
     }
-  } else { # } paralell settings
+  } else { # end paralell settings
     if(loops){
       tic()
       for(it in 1:rsit){
@@ -318,24 +324,26 @@ RS_opt <- function(poped.db,
           aoptn=aoptn-((aoptn>maxa)*(aoptn-maxa))
           aoptn=aoptn+((aoptn<mina)*(mina-aoptn))
         }
-
-        nfmf <- evaluate.fim(poped.db,
-                             bpop.val=bpop,
-                             d_full=d,
-                             docc_full=docc_full,
-                             sigma_full=poped.db$parameters$sigma,
-                             model_switch=model_switch,
-                             ni=ni,
-                             xt=xtoptn,
-                             x=xoptn,
-                             a=aoptn,
-                             groupsize=poped.db$design$groupsize,
-                             fim.calc.type=fim.calc.type,
-                             ...)
-        #         returnArgs <- mftot(model_switch,poped.db$design$groupsize,ni,xtoptn,xoptn,aoptn,bpop,d,poped.db$parameters$sigma,docc_full,poped.db) 
-        #         nfmf <- returnArgs[[1]]
-        #         poped.db <- returnArgs[[2]]
-        ndmf=ofv_fim(nfmf,poped.db,...)
+        
+        output <- calc_ofv_and_fim(poped.db,
+                                   d_switch=d_switch,  
+                                   bpopdescr=bpopdescr, 
+                                   ddescr=ddescr,
+                                   bpop=bpop, 
+                                   d=d, 
+                                   docc_full= docc_full, 
+                                   model_switch=model_switch, 
+                                   ni=ni, 
+                                   xt=xtoptn, 
+                                   x=xoptn, 
+                                   a=aoptn, 
+                                   fim.calc.type=fim.calc.type,
+                                   use_laplace=use_laplace,
+                                   laplace.fim=FALSE, 
+                                   ...)
+        nfmf <- output$fim
+        ndmf <- output$ofv            
+        if(is.nan(ndmf)) ndmf  <- 0
         if((ndmf>dmf)){
           if((optxt==TRUE)){
             xtopt=xtoptn
@@ -362,11 +370,12 @@ RS_opt <- function(poped.db,
           write_iterationfile('Random Search',it,xtopt,aopt,xopt,ni,poped.db$design$groupsize,fmf,dmf,poped.db)
         }
         
-        if((trflag && (rem(it,rsit_output)==0 || trflag && it==rsit))){
+        if((trflag && ((it %% rsit_output)==0 || trflag && it==rsit))){
           itvector[ceiling(it/rsit_output)+1]=it
           dmfvector[ceiling(it/rsit_output)+1]=dmf
           # fix so that the iterations are output to summary file.
-          Dtrace(fn,it,ni,xtopt,xopt,aopt,matrix(0,0,0),matrix(0,0,0),dmf,matrix(0,0,0),matrix(0,0,0),matrix(0,0,0),itvector,dmfvector,poped.db,
+          Dtrace(fn,it,ni,xtopt,xopt,aopt,matrix(0,0,0),matrix(0,0,0),
+                 dmf,matrix(0,0,0),matrix(0,0,0),matrix(0,0,0),itvector,dmfvector,poped.db,
                  rsit=rsit,opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x)
         }
       }
@@ -386,18 +395,41 @@ RS_opt <- function(poped.db,
   poped.db$design$x <-xopt
   poped.db$design$a <-aopt
   
+  
+  # make sure that both the OFV and FIM exists, calculate if not there
+  output <- calc_ofv_and_fim(poped.db,
+                             ofv=dmf,
+                             fim=fmf, 
+                             d_switch=d_switch,  
+                             bpopdescr=bpopdescr, 
+                             ddescr=ddescr,
+                             bpop=bpop, 
+                             d=d, 
+                             docc_full= docc_full, 
+                             model_switch=model_switch, 
+                             ni=ni, 
+                             xt=xt, 
+                             x=x, 
+                             a=a, 
+                             fim.calc.type=fim.calc.type,
+                             use_laplace=use_laplace,
+                             laplace.fim=laplace.fim, 
+                             ...)
+  fmf <- output$fim
+  dmf <- output$ofv
+  
+  
   #--------- Write results
-  if((trflag)){
-    blockfinal(fn,fmf,dmf,poped.db$design$groupsize,ni,xtopt,xopt,aopt,model_switch,bpopdescr,ddescr,poped.db$parameters$docc,poped.db$parameters$sigma,poped.db,
-                 opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,fmf_init=fmf_init,dmf_init=dmf_init,param_cvs_init=param_cvs_init)
-    #close(fn)
-  }
-  
-  #==========================================
-  # turn warnings on
-  #==========================================
-  ## warning('on','MATLAB:nearlySingularMatrix');
-  
+  #if((trflag)){
+  #  if(footer_flag){
+  blockfinal(fn,fmf,dmf,poped.db$design$groupsize,ni,xtopt,xopt,aopt,model_switch,
+               bpopdescr[,2],ddescr,poped.db$parameters$docc,poped.db$parameters$sigma,poped.db,
+               opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,fmf_init=fmf_init,
+               dmf_init=dmf_init,compute_inv=compute_inv,
+               out_file=out_file,trflag=trflag,
+               footer_flag=footer_flag,...)
+  #  }
+  #}
   
   invisible(list( xtopt= xtopt,xopt=xopt,aopt=aopt,fmf=fmf,dmf=dmf,poped.db =poped.db )) 
 }
