@@ -1,7 +1,7 @@
 ## Function written to match MATLAB function
 ## Author: Andrew Hooker
 
-fprintf <- function(file="",...){
+fprintf <- function(file="",...,both=FALSE){
   if(any(class(file)=="file")){
     cat(sprintf(...),file=file)
   } else {
@@ -9,4 +9,7 @@ fprintf <- function(file="",...){
       cat(sprintf(file,...))
     }
   }
+  if(both && file!=""){
+    cat(sprintf(...))
+  }
 }
