@@ -15,6 +15,7 @@
 #' rows and columns of the FIM: det(FIM)/det(FIM_u)
 #' \item 7 = Inverse of the sum of the expected parameter RSE: 1/sum(get_rse(FIM,poped.db,use_percent=FALSE))
 #' }
+#' @param use_log Should the criterion be in the log domain?
 #' @inheritParams RS_opt
 #' @inheritParams Doptim
 #' @inheritParams create.poped.database
@@ -33,7 +34,9 @@
 
 ofv_fim <- function(fmf,poped.db,
                     ofv_calc_type = poped.db$settings$ofv_calc_type,
-                    ds_index=poped.db$parameters$ds_index,...){
+                    ds_index=poped.db$parameters$ds_index,
+                    use_log = TRUE,
+                    ...){
   
   #Input: the FIM
   #Return the single value that should be maximized
@@ -81,7 +84,11 @@ ofv_fim <- function(fmf,poped.db,
     tmp = fmf
     tmp <- tmp[c(col(ds_index)[ds_index==1]),,drop=F]
     tmp <- tmp[,c(col(ds_index)[ds_index==1]),drop=F]
-    ofv_value = det(fmf)/det(tmp)
+    if(use_log){
+      ofv_value = log(det(fmf))-log(det(tmp))
+    } else {
+      ofv_value = det(fmf)/det(tmp)  
+    }
   }
   if((ofv_calc_type==7) ){#sum of CV
     if((sum(sum(fmf))!=0 && !is.nan(sum(sum(fmf))))){
