@@ -1,4 +1,3 @@
-# warfarin optimize model
 
 # Adding 40% Uncertainty to fixed effects log-normal (not Favail)
 bpop_vals <- c(CL=0.15, V=8, KA=1.0, Favail=1)
@@ -9,7 +8,7 @@ bpop_vals_ed_ln["Favail",]  <- c(0,1,0)
 
 pars.ln <- pargen(par=bpop_vals_ed_ln,
                user_dist_pointer=NULL,
-               sample_size=100,
+               sample_size=1000,
                bLHS=1,
                sample_number=NULL,
                poped.db)
@@ -23,7 +22,7 @@ bpop_vals_ed_n["Favail",]  <- c(0,1,0)
 
 pars.n <- pargen(par=bpop_vals_ed_n,
                user_dist_pointer=NULL,
-               sample_size=100,
+               sample_size=1000,
                bLHS=1,
                sample_number=NULL,
                poped.db)
@@ -37,9 +36,28 @@ bpop_vals_ed_u["Favail",]  <- c(0,1,0)
 
 pars.u <- pargen(par=bpop_vals_ed_u,
                  user_dist_pointer=NULL,
-                 sample_size=100,
+                 sample_size=1000,
                  bLHS=1,
                  sample_number=NULL,
                  poped.db)
 
 
+# Adding user defined distributions
+bpop_vals_ed_ud <- cbind(ones(length(bpop_vals),1)*3, # user dfined distribution
+                         bpop_vals,
+                         bpop_vals*0.1) # 10% of bpop value
+bpop_vals_ed_ud["Favail",]  <- c(0,1,0)
+
+# A normal distribution
+my_dist <- function(...){
+  par_vec <- rnorm(c(1,1,1,1),mean=bpop_vals_ed_ud[,2],sd=bpop_vals_ed_ud[,3])
+}
+
+pars.ud <- pargen(par=bpop_vals_ed_ud,
+                  user_dist_pointer=my_dist,
+                  sample_size=1000,
+                  bLHS=1,
+                  sample_number=NULL,
+                  poped.db)
+
+
